summary refs log tree commit diff stats
diff options
context:
space:
mode:
-rw-r--r--doc/examples/plugin_file_filter.py18
1 files changed, 10 insertions, 8 deletions
diff --git a/doc/examples/plugin_file_filter.py b/doc/examples/plugin_file_filter.py
index bad5a368..b9bea1f3 100644
--- a/doc/examples/plugin_file_filter.py
+++ b/doc/examples/plugin_file_filter.py
@@ -1,18 +1,20 @@
-# Compatible with ranger 1.6.*
+# Compatible since ranger 1.6.1, git commit c82a8a76989c
 #
 # This plugin hides the directories "boot", "sbin", "proc" and "sys" in the
 # root directory.
 
 # Save the original filter function
 import ranger.container.directory
 old_accept_file = ranger.container.directory.accept_file
 
+HIDE_FILES = ("/boot", "/sbin", "/proc", "/sys")
+
 # Define a new one
-def custom_accept_file(fname, directory, hidden_filter, name_filter):
-       if hidden_filter and directory.path == '/' and fname in ('boot', 'sbin', 'proc', 'sys'):
-               return False
-       else:
-               return old_accept_file(fname, directory, hidden_filter, name_filter)
+def custom_accept_file(file, filters):
+    if not file.fm.settings.show_hidden and file.path in HIDE_FILES:
+        return False
+    else:
+        return old_accept_file(file, filters)
 
 # Overwrite the old function
 import ranger.container.directory
@@ -1,18 +1,20 @@
 #
-# This plugin hides the directories "boot", "sbin", "proc" and "sys" in the
-# root directory.
+# This plugin hides the directories "/boot", "/sbin", "/proc" and "/sys" unless
+# the "show_hidden" option is activated.
 
 # Save the original filter function